@@ -1,6 +1,6 @@
 use std::error::Error;
 
-use super::Args;
+use super::Command;
 use crate::weather_api::{Client, Location};
 use clap::Parser;
 
@@ -13,8 +13,8 @@ pub struct LocationCommand {
 }
 
 impl LocationCommand {
-	pub fn run(&self, args: &Args) -> Result<(), Box<dyn Error>> {
-		let client = Client::new().login(args.key.clone());
+	pub fn run(&self, command: &Command) -> Result<(), Box<dyn Error>> {
+		let client = Client::new().login(command.key.clone());
 
 		let location = Location::from_string(&client, &self.location)?;
 
